@@ -20,8 +20,10 @@
 #include <gpe/smallbox.h>
 
 #include "sql.h"
+#include "html.h"
 
 #define _(_x) gettext(_x)
+#define JOURNAL_FILE "/tmp/journal.html"
 
 static const guint window_x = 240, window_y = 320;
 
@@ -35,11 +37,45 @@ struct gpe_icon my_icons[] = {
   { NULL, NULL }
 };
 
+
 static GdkWindow *top_level_window;
 
 static GtkWidget *btn_con, *btn_coff;
 
 
+/*
+ * stop any clocked in task 
+ * not efficient, but works
+ */
+static void
+stop_timing_all(GtkCTree *ct)
+{
+  GSList *aitem;
+  struct task *t;
+
+  for (aitem=root;aitem;aitem=aitem->next)
+    {
+      t = aitem->data;  
+      if (t->started)
+	    {
+          GtkCTreeNode *node = gtk_ctree_find_by_row_data(ct,NULL,t);
+		  gtk_ctree_node_set_text (ct, node, 1, "");
+          log_entry (STOP, time (NULL), t, "");
+          t->started = FALSE;
+        }
+    }
+}
+
+static gboolean
+exit_app (GtkWidget *w, GdkEvent *evt, gpointer user_data)
+{
+  GtkCTree *ct = GTK_CTREE(user_data);
+	
+  stop_timing_all(ct);	
+	
+  return FALSE;
+}
+
 static void
 journal (GtkWidget *w, gpointer user_data)
 {
@@ -49,8 +85,12 @@ journal (GtkWidget *w, gpointer user_data)
       GtkCTreeNode *node = GTK_CTREE_NODE (GTK_CLIST (ct)->selection->data);
       struct task *t;
       t = gtk_ctree_node_get_row_data (ct, node);
-	  /* here we go... */
-	  
+      /* here we go... */
+      journal_add_header(t->description);
+      scan_journal(g_slist_find(root,t));
+      journal_add_footer();
+      journal_to_file(JOURNAL_FILE);
+      journal_show(JOURNAL_FILE);
     }
 }
 
@@ -207,6 +247,7 @@ start_timing (GtkWidget *w, gpointer user_data)
       GtkCTreeNode *node = GTK_CTREE_NODE (GTK_CLIST (ct)->selection->data);
       struct task *t;
       gchar *text;
+	  stop_timing_all(ct); /* we allow only one task to be clocked in */
       t = gtk_ctree_node_get_row_data (ct, node);
       if (confirm_dialog (&text, _("Clocking in:"), t->description))
 	{
@@ -227,9 +268,9 @@ stop_timing (GtkWidget *w, gpointer user_data)
     {
       GtkCTreeNode *node = GTK_CTREE_NODE (GTK_CLIST (ct)->selection->data);
       struct task *t;
-      gchar *text;
+      gchar *text = " ";
       t = gtk_ctree_node_get_row_data (ct, node);
-      if (confirm_dialog (&text, _("Clocking out:"), t->description))
+/*      if (confirm_dialog (&text, _("Clocking out:"), t->description))*/
 	{
 	  gtk_ctree_node_set_text (ct, node, 1, "");
 	  log_entry (STOP, time (NULL), t, text);
@@ -339,12 +380,12 @@ tree_select_row (GtkCTree *ct, GList *node, gint col, gpointer data)
       t = gtk_ctree_node_get_row_data (ct, node);
       if (t->started)
         {
-	  set_active (0, 1);
-	}
+          set_active (0, 1);
+        }
       else
-	{
-	  set_active (1, 0);
-	}
+        {
+          set_active (1, 0);
+        }
     }
 }
 
@@ -376,7 +417,6 @@ main(int argc, char *argv[])
 
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar), GTK_ORIENTATION_HORIZONTAL);
-  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
 
   tree = gtk_ctree_new (2, 0);
   g_signal_connect (G_OBJECT(tree), "tree-select-row",
@@ -424,13 +464,11 @@ main(int argc, char *argv[])
 			   _("Note"), _("Note"),
 			   pw, (GtkSignalFunc)note, tree);
 
-#if 0
   p = gpe_find_icon ("journal");
   pw = gtk_image_new_from_pixbuf (p);
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar), _("Journal"),
 			   _("Show journal"), _("Show journal"),
 			   pw, (GtkSignalFunc)journal, tree);
-#endif
 			   
   gtk_widget_show (toolbar);
   gtk_widget_show (vbox_top);
@@ -444,8 +482,11 @@ main(int argc, char *argv[])
   gtk_widget_set_usize (window, window_x, window_y);
 
   g_signal_connect (G_OBJECT (window), "delete-event", 
-		    G_CALLBACK (gtk_main_quit), NULL);
+		    G_CALLBACK (exit_app), (void *)tree);
 
+  g_signal_connect_after (G_OBJECT (window), "delete-event", 
+		    G_CALLBACK (gtk_exit), NULL);
+			
   gtk_widget_realize (window);
 
   gpe_set_window_icon (window, "gpe-timesheet");
